package MyTest::Control::Flow::Minimal::FTwo;

use strict;
use warnings;

use Class::Std::Storable;
use base qw(MyTest::Control::Flow::Minimal::_FTwo);

1;

__END__

=pod

=head1 NAME

MyTest::Control::Flow::Minimal::FTwo - auto-generated by Hyper Framework

=head1 DESCRIPTION

All functionality is inherited from
MyTest::Control::Flow::Minimal::_FTwo

Override methods by re-implementing them here if needed.

=head1 COPYING


=head1 AUTHOR

 Generated by Hyper::Generator::Flow

=cut
